game_qu.library_abstraction API documentation
Description: This file holds the module variables that the game engine will be getting its functions and constants from (either pygame or pyglet)

# Module `game_qu.library_abstraction`

This file holds the module variables that the game engine will be getting its functions and constants from (either pygame or pyglet)

Expand source code

    """This file holds the module variables that the game engine will be getting its functions and constants from (either pygame or pyglet)"""

    keys = None
    variables = None
    utility_functions = None